libname temp "H:\Workshops\Issues in Analysis of Complex Sample Survey Data\SAS Data";

/* initial subpop examples */

data temp1 (keep = fwgtexam ppsu stratum bpsyst b50subp);
   set temp.nhanes;
   if (race = 2 and ager >= 50) then b50subp = 1;
   else b50subp = 0;
run;

proc surveymeans data = temp1;
   where b50subp = 1;
   weight fwgtexam;
   stratum stratum;
   cluster ppsu;
   var bpsyst;
run;

proc surveymeans data = temp1;
   domain b50subp;
   weight fwgtexam;
   stratum stratum;
   cluster ppsu;
   var bpsyst;
run;

/* regression example #1 */

data nhanes;
   set temp.nhanes;
   if ager lt 18 then delete;
   logdbp = log(bpdiast);
   agesq = ager*ager;
   igender = 0;
   if gender = 2 then igender = 1; /* 1 = female, 0 = male */
   black = 0;
   if race = 2 then black = 1;
   other = 0;
   if race = 3 then other = 1;
   if race = . then other = .;
   if race = . then black = .;
   if ager >= 18 then age18 = 1;
   else age18 = 0;
   bmi = weightkg*100*100/(heightcm*heightcm);
   wgt_norm = fwgtexam / 11334.59;
run;

proc means data = nhanes;
   var fwgtexam;
run;

proc reg data = nhanes;
   model logdbp = ager igender black other povindex bmi / clb;
run;
quit;

/* regression example #2 */

proc surveyreg data = nhanes;
   stratum stratum;
   cluster ppsu;
   weight fwgtexam;
   model logdbp = ager igender black other povindex bmi / clparm;
run;

/* surveymeans example */

data lsoa;
   set temp.lsoa_86x;
   if cancer = 2 then nevercanc = 1;
   else if cancer = 1 then nevercanc = 0;
run;

proc surveymeans data = lsoa;
   stratum stratum;
   cluster psu;
   weight fnlwgt2;
   var nevercanc;
run;

/* IVEware cancer example */

%describe(name = desc1, dir=c:\temp, setup=new);                                                                                        
datain lsoa;                                                                                                                   
stratum stratum;                                                                                                                        
cluster psu;                                                                                                                            
weight fnlwgt2;                                                                                                                         
mean nevercanc;                                                                                                                            
run;

/* crosstab example */

proc surveyfreq data = nhanes;
   stratum stratum;
   cluster ppsu;
   weight fwgtexam;
   tables gender*race / chisq;
run;

/* subpop note */

proc surveyfreq data = nhanes;
   stratum stratum;
   cluster ppsu;
   weight fwgtexam;
   tables age18*gender*race / chisq;
run; 

/* IVEware regression example */

%regress(name = reg1, dir=c:\temp, setup=new);
datain nhanes;
stratum stratum;
cluster ppsu;
weight fwgtexam;
predout pred1;
plots plots1;
link LINEAR;
dependent logdbp;
predictor ager igender black other povindex bmi;
run;

/* logistic regression example */

data lsoa_male;
   set temp.lsoa_86x;
   if sex = 1 then maleind = 1;
   else if sex = 2 then maleind = 0;
   if cancer = 1 then evercanc = 1;
   else if cancer = 2 then evercanc = 0;
run;

proc surveylogistic data = lsoa_male;
   class evercanc / DESC;
   cluster psu;
   strata stratum;
   weight fnlwgt2;
   domain maleind;
   model evercanc = height weight educ age84;
run;

/* Poisson regression analysis in IVEware */

data lsoa86;
   set lsoa;
   adloff = 7;
   age86 = age84 + 2;
run;

%regress(setup = new, name = pois1, dir = c:\temp);
datain lsoa86;
stratum stratum;
cluster ppsu;
weight fnlwgt2;
offsets numadl2r(adloff);
categorical sex cataract coronhtd diabetes;
dependent numadl2r;
predictor age86 sex cataract coronhtd diabetes incfamr numdaugh;
predout adlpred1;
link log;
run;

/* Cox regression analysis using IVEware */

libname ncs "H:\Workshops\ISR - Analysis of Survey Data\Data Sets";

proc freq data = ncs.ncsdxdm3;
   tables alcalt1;
run;

data ncs;
   set ncs.ncsdxdm3;
   if alcaonsa ne . then ageabuse = alcaonsa;
   else ageabuse = age;
run;

%regress(setup = new, name = phreg, dir = c:\temp);
datain ncs;
stratum str;
cluster secu;
weight p1fwt;
dependent ageabuse;
censor alcalt1(0);
predictor sexf ag15 ag25 ag35;
link PHREG;
run;

/* multiple imputation using IVEware */

libname temp "C:\";

data nes2000a;
   set temp.nes2000a;
run;

/* conduct multiple imputation */
%impute(name = imp1, dir=c:\temp, setup=new);
datain nes2000a;
dataout nesimp;
default categorical;
continuous age fam_income educ;
transfer new_strat new_clust weight;
bounds age(>=18,<=25) fam_income(>=1,<=22) educ(>=0,<=17);
iterations 5;
multiples 5;
seed 41279;
run;

/* output imputed data sets */
%putdata(name=imp1,dir=c:\temp,mult=1,dataout=nesimp1);
%putdata(name=imp1,dir=c:\temp,mult=2,dataout=nesimp2);
%putdata(name=imp1,dir=c:\temp,mult=3,dataout=nesimp3);
%putdata(name=imp1,dir=c:\temp,mult=4,dataout=nesimp4);
%putdata(name=imp1,dir=c:\temp,mult=5,dataout=nesimp5);

/* perform logistic regression analysis on imputed data sets */
%regress(name = reg1, dir=c:\temp, setup=new);
datain nesimp1 nesimp2 nesimp3 nesimp4 nesimp5;
stratum new_strat;
cluster new_clust;
weight weight;
link LOGISTIC;
dependent vote(0);
predictor fam_income gender active educ proximity marital age;
run;







